package App::ZshCompleteUtils;

our $DATE = '2016-10-27'; # DATE
our $VERSION = '0.001'; # VERSION

use 5.010001;
use strict;
use warnings;

1;
# ABSTRACT: Utilities related to zsh completion

__END__

=pod

=encoding UTF-8

=head1 NAME

App::ZshCompleteUtils - Utilities related to zsh completion

=head1 VERSION

This document describes version 0.001 of App::ZshCompleteUtils (from Perl distribution App-ZshCompleteUtils), released on 2016-10-27.

=head1 SYNOPSIS

=head1 DESCRIPTION

This distribution includes the following utilities:

# INSERT_EXECS_LIST

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-ZshCompleteUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-ZshCompleteUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ZshCompleteUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
